# Hammit

Have you ever wanted to calculate the hamming distance between two strings? Well here's a library for that.

## Usage

```
>>> from hammit import distance
>>> distance('123','122')
1 
```

A return value of -1 indicates the hamming distance could not be computed.
